@@ -106,7 +106,7 @@
                             :format-control "NUM-BITS is too big for a DSA key."))))
          (q (generate-prime n))
          (p (loop for z = (logior (ash 1 (- num-bits n 1))
-                                  (random-bits (- num-bits n)))
+                                  (dpb 0 (byte 1 0) (random-bits (- num-bits n))))
                   for p = (1+ (* z q))
                   until (and (= num-bits (integer-length p))
                              (prime-p p))
